==============
steganographer
==============
.. image:: https://travis-ci.org/MotaDan/steganographerPY.svg?branch=master
   :target: https://travis-ci.org/MotaDan/steganographerPY
.. image:: https://coveralls.io/repos/github/MotaDan/steganographerPY/badge.svg?branch=image_compatibility
   :target: https://coveralls.io/github/MotaDan/steganographerPY?branch=image_compatibility
.. image:: https://landscape.io/github/MotaDan/steganographerPY/image_compatibility/landscape.svg?style=flat
   :target: https://landscape.io/github/MotaDan/steganographerPY/image_compatibility
   :alt: Code Health


Hide messages inside an image. 


Description
===========

Given an image and a message steganographer will hide the message in the bits of the image. Currently only works for pngs.
